pub fn into_group_map_with_hasher<I, K, V, S>(
iter: I,
hash_builder: S,
) -> HashMap<K, Vec<V>, S>Expand description
Return a HashMap of keys mapped to a list of their corresponding values.
See .into_group_map()
for more information.
pub fn into_group_map_with_hasher<I, K, V, S>(
iter: I,
hash_builder: S,
) -> HashMap<K, Vec<V>, S>Return a HashMap of keys mapped to a list of their corresponding values.
See .into_group_map()
for more information.